/////////////////////////////////////////////////////////////////////////////
// @doc PointObj
// @module PointObj.Java | Implementation of the <c PointObj> class.
// 
// Rosa2000 Applet<tm>
// <nl>Copyright <cp> 1999, 2000, DM Solutions Group Inc. All rights reserved.
// 
// Author:  Guy Parent
//
// $Id: PointObj.java,v 1.3 2000/08/18 14:23:17 assefa Exp $
// 
/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 1999, 2000, DM Solutions Goup Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
/////////////////////////////////////////////////////////////////////////////
// $Log: PointObj.java,v $
// Revision 1.3  2000/08/18 14:23:17  assefa
// Use double buffering when drawing (rectangle, circle..) instead of XOR.
//
// Revision 1.2  2000/04/06 11:26:19  gparent
// Fixed a drawing bug using default selection
//
// Revision 1.1  2000/01/28 20:16:30  daniel
// Initial Revision
//
/////////////////////////////////////////////////////////////////////////////


import java.awt.Point;
import java.awt.Graphics;
import java.awt.event.MouseListener;
import java.awt.event.MouseEvent;                                        
import java.lang.Integer;


/** 
 * This class handle a point commant. When active, it wait a mouse click and
 * commit the operation.
 *
 * @author  Guy Parent
 */
public class PointObj extends DrawObj
  implements MouseListener
{
  /** X coordinate */
  protected int x = 0;
  /** Y coordinate */
  protected int y = 0;

  /** Map object.  */
  Map     m_map;

  
  public PointObj( Map parent )
  {
    
    m_map = parent;
    g = parent.getGraphics();

    // Active the event.
    addEvent();
 
  }
  
  /** 
   * Create the submit string. The point data likes ValueX,ValueY
   */
  public String getSubmitValue()
  {
    String strRetVal = Integer.toString( x ) + "," + Integer.toString( y );
    return strRetVal;
  }

  /**
   * Destroy the mouse listener.
   */
  public void  destroyEvent()
  {
    m_map.removeMouseListener( this );
  }

    public void  addEvent()
    {
        m_map.addMouseListener( this );
    }
  /**
   * Commit the operation.
   */
  public void mouseReleased (MouseEvent evt)
  {
      x = evt.getPoint().x;
      y = evt.getPoint().y;

      
      m_map.redraw();
      
    // Remove the event
    //destroyEvent();

      m_map.commitOperation();
  }

  /**
   * After the mouse release, this method draw a cross at the mouse click
   * location.
   */
  public void draw()
  {
      if( g == null )      
        g = m_map.getGraphics();    
      if( g != null )
      {
          g.drawLine( x-2, y, x+2, y );
          g.drawLine( x, y-2, x, y+2 );
      }
  }

    /**
     * reset the object.
     */
    public void reset_object()
    {
        x = 0;
        y = 0;
    }
      
  // Dummy methods.
  /** Not used     */
  public void mouseEntered (MouseEvent evt){} 
  /** Not used     */
  public void mouseExited (MouseEvent evt){}
  /** Not used     */
  public void mouseClicked (MouseEvent evt){}

  /** Not used     */
  public void resize (Point p){ }
  /** Not used     */
  public void mousePressed (MouseEvent evt) {}
}
