/////////////////////////////////////////////////////////////////////////////
// @doc PointObj
// @module PointObj.Java | Implementation of the <c PointObj> class.
// 
// Rosa2000 Applet<tm>
// <nl>Copyright <cp> 1999, 2000, DM Solutions Group Inc. All rights reserved.
// 
// Author:  Guy Parent
//
// $Id: PolyObj.java,v 1.3 2000/08/18 14:23:17 assefa Exp $
// 
/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 1999, 2000, DM Solutions Goup Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
/////////////////////////////////////////////////////////////////////////////
// $Log: PolyObj.java,v $
// Revision 1.3  2000/08/18 14:23:17  assefa
// Use double buffering when drawing (rectangle, circle..) instead of XOR.
//
// Revision 1.2  2000/05/30 16:22:10  daniel
// Fixed getSubmitValue() that did not include a ';' before last coord. pair
//
// Revision 1.1  2000/01/28 20:16:30  daniel
// Initial Revision
//
/////////////////////////////////////////////////////////////////////////////


import java.awt.Point;
import java.awt.Graphics;
import java.awt.Color;                      
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseListener;
import java.awt.event.MouseEvent;
import java.awt.event.KeyListener;
import java.awt.event.KeyEvent;
import java.awt.Polygon;

/**
 * This class is used to draw a polygon.  It will submit a set of xy coordinate.
 * Each mouse click will create a new vertex in the polygon.
 */
public class PolyObj extends DrawObj
            implements MouseMotionListener, MouseListener, KeyListener
{
    
    protected Point pAnchor;          // used for initial drawing and resizing
    protected Point pMoveAnchor;      // used for moving

    /** Polygon */
    protected Polygon m_poly = new Polygon();
    
    protected Map     m_map;
    Rosa2000    m_applet;
    
    /**
     * Constructor.
     */
    public PolyObj( Map parent, Rosa2000 applet )
    {
        m_applet = applet;
        
        m_map = parent;
        g = parent.getGraphics();

        // Active the event.
        addEvent();
    }
    

    /**
     * Create the submit string. It will be format likes x1,y1;x2,y2...
     */
    public String getSubmitValue()
    {
        String strRetVal = new String();
        
        for( int i = 0; i < m_poly.npoints; i++ )
        {
            strRetVal += Integer.toString( m_poly.xpoints[i] )  + "," + 
                                Integer.toString( m_poly.ypoints[i] );
            
            if( i < m_poly.npoints - 1 )
                strRetVal += ";";
        }
        return strRetVal;
    }

/**
     * Draw the polyline
     */
    public  void draw()
    {
        if (g != null && m_poly.npoints > 0)
        {
            Color colorCurrent = g.getColor();
            g.setColor( this. getColor());
                
            g.drawPolyline(m_poly.xpoints, m_poly.ypoints, m_poly.npoints);
            g.setColor( colorCurrent );
            drawLine();
        }
    }

    /**
     * Draw the latest edge between the last vertex and the current mouse position.
     */
    public  void drawLine()
    {
        
        if (g != null && m_poly.npoints > 0)
        {
            Color colorCurrent = g.getColor();
            g.setColor( this. getColor());
                
            g.drawLine( pAnchor.x,  pAnchor.y,  
                        pMoveAnchor.x,  pMoveAnchor.y );
            g.setColor( colorCurrent );
        }
    }
    

    /**
     * Paint the initial polygon.
     */
    public void initPaint ()
    {
        Graphics g = m_map.getGraphics();
        if (g != null)
        {
            //this.setColor(Color.white);

            m_map.redraw();
            //m_map.drawImageToBuffer();
            //draw();
            //drawLine();
            //m_map.pushImageToScreen();
            //g.setPaintMode();
        }
    }
    

    //////////////////////////////////////////////////////////////////////////
    // MouseMotionListener implementation
    /// MouseDragged

    /**
     * Called by the framework. Draw the lastest edge.
     */
    public void mouseMoved (MouseEvent evt)
    {
        Graphics g = m_map.getGraphics();
        if (g != null && m_poly.npoints  > 0 )
        {
            // Undraw
            //g.setXORMode( Color.black );
            //draw();
            
            pMoveAnchor = evt.getPoint();
            initPaint();
        }
    }
    
    
    //////////////////////////////////////////////////////////////////////////
    /**
     * Add a new vertex in the polygon.
     */
    public void mousePressed (MouseEvent evt)
    {
        if( evt.getClickCount() == 2 )
        {
            endProcessing();
        }
        else
        {
            m_poly.addPoint( evt.getX(), evt.getY() );
                             
            pAnchor = evt.getPoint();
            pMoveAnchor = pAnchor;
            m_map.redraw();
        }           
            
    }
    
    /**
     * Destroy the mouse listener, mouse motion listener and the key listener
     */
    public void  destroyEvent()
    {
            m_map.removeMouseListener( this );
            m_map.removeMouseMotionListener( this );
            m_applet.removeKeyListener( this );
    }
    
    /**
     * add the mouse listener, mouse motion listener and the key listener
     */
    public void addEvent()
    {
        m_map.addMouseListener( this );
        m_map.addMouseMotionListener( this );
        m_applet.addKeyListener( this );
    }
    /** 
     * Destroy the event listener and commit the operation.
     */
    public void endProcessing()
    {
            // Remove the event
        destroyEvent();
        m_map.commitOperation();
        
    }
    
    /** Not used.    */
    public void mouseReleased (MouseEvent evt)
    {
        
    }

    /**
     * Stop the operation. If the user pressed on enter or space bar, it will submit the polygon,
     * if he press on escape key, it will abort. 
     */
    public void keyPressed( KeyEvent e ) 
    {
        if( e.getKeyCode() == KeyEvent.VK_ENTER  ||
            e.getKeyCode() == KeyEvent.VK_SPACE )
        {
            endProcessing();    
        }
        else if( e.getKeyCode() == KeyEvent.VK_ESCAPE ) 
        {
            m_poly = new Polygon();
            endProcessing();
        }
        
    }
    
    /**
     * reset the object.
     */
    public void reset_object()
    {
        m_poly = new Polygon();
    }
    // Dummy methods
    /** Not used     */
    public void resize (Point p) { }
    /** Not used     */
    public void mouseDragged ( MouseEvent evt ) { }
    /** Not used     */
    public void mouseEntered (MouseEvent evt) { }
    /** Not used     */
    public void mouseExited (MouseEvent evt) { }
    /** Not used     */
    public void mouseClicked (MouseEvent evt) { }
    /** Not used     */
    public void keyReleased( KeyEvent e )  { }
    /** Not used     */
    public void keyTyped( KeyEvent e )  { }

}
