/////////////////////////////////////////////////////////////////////////////
// @doc RoundButton
// @module RoundButton.Java | Implementation of the <c RoundButton> class.
// 
// Rosa2000 Applet<tm>
// <nl>Copyright <cp> 1999, 2000, DM Solutions Group Inc. All rights reserved.
// 
// Author:  Guy Parent
//
// $Id: RoundButton.java,v 1.3 2002/08/08 15:37:56 sacha Exp $
// 
/////////////////////////////////////////////////////////////////////////////
// Copyright (c) 1999, 2000, DM Solutions Goup Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
/////////////////////////////////////////////////////////////////////////////
// $Log: RoundButton.java,v $
// Revision 1.3  2002/08/08 15:37:56  sacha
// Put back toolba button when printing but not for Netscape. I still have a problem in netscape. So I just removed the toolbar in Netscape when printing.
//
// Revision 1.2  2000/02/04 15:02:33  gparent
// Added doccumentation.
//
// Revision 1.1  2000/01/28 20:16:30  daniel
// Initial Revision
//
/////////////////////////////////////////////////////////////////////////////


import java.applet.Applet;
import java.awt.Graphics;
import java.awt.Image;

/**
 * RoundButton is a class to manage a button using two images.  The handling 
 * is the same as RectButton but no border is drawn.  The first image is used to 
 * display an unpress button and the second one is the press button. 
 *  
 */
public class RoundButton extends ButtonCtrl
{
    private Image m_ImagePress;
    
    /**
     * Constructor.
     * @param strName Button name. This string will be used to load all paramerter from the applet.
     * @param img It's the image on the button.
     * @param imgPress It's the image on the button in the pressed state.
     * @param bAutoPress <b>true</b> is the button will be automaticaly unpress after the action.
     * @param applet Used to draw tooltips.
     */
    public RoundButton(String strName,  Image img, Image impPress,  boolean bAutoPress, Rosa2000 applet ) 
    { 
        super( strName, bAutoPress, applet );
        m_Img               = img;
        m_ImagePress    = impPress;
        init();
        if( Rosa2000.isDebugMode() == true )
            System.out.println("RoundButton Constructor");

    } 

    public RoundButton(String strName,  Image img, Image impPress, 
                                  int nXSize, int nYSize, boolean bAutoPress, Rosa2000 applet ) 
    { 
        super( strName, nXSize, nYSize, bAutoPress, applet );
        m_Img               = img;
        m_ImagePress    = impPress;
        init();
        if( Rosa2000.isDebugMode() == true )
            System.out.println("RoundButton Constructor");
    }
    
    
    /**
     * Paint the current button. No border is drawing.
     */
    public void paint(Graphics g) 
    { 
        if (m_bPressed) 
        { 
            g.drawImage( m_ImagePress, 0,0, this); 
        }
        else 
        { 
            g.drawImage(m_Img,0,0, this);
        }
    }

    public void printAll(Graphics g)
    {
	print(g);
    }

    public void print(Graphics g)
    {
	/* 
	   Netscape print the applet a little bigger than the
	   original component size. This cause netscape to print
	   the applet over some html component. To fix that, we
	   must resize the final result by 75%. This is documented
	   at this place: 

	   http://www.caff.de/workarounds/index.shtml#common_printing

	   If it is not netscape, use a scale factor of 100%
	*/

	double scale=0.75;

	// if not netscape set scale to 100%
	try 
	{
	    Class.forName("netscape.applet.MozillaAppletContext");
	} 
	catch (ClassNotFoundException e) 
	{ 
	    scale = 1.0;
	}

        if (m_bPressed) 
        { 
            g.drawImage(m_ImagePress,0,0, (int)(m_ImagePress.getWidth(this)*scale), (int)(m_ImagePress.getHeight(this)*scale), this); 
        }
        else 
        { 
            g.drawImage(m_Img,0,0, (int)(m_ImagePress.getWidth(this)*scale), (int)(m_ImagePress.getHeight(this)*scale), this); 
        }	
    }
    
}
